@@ -46,4 +46,4 @@ fcolors = {
 
 
 def cprint(data, color='yellow', bcolor='black', enable=COLORS):
-    print(f"{bcolors[bcolor]}{fcolors[color]}{data}{fcolors['reset']}" if enable else data)
+    print(f"{bcolors[bcolor]}{fcolors[color]}{data}{fcolors['reset']}" if enable else data, end='')
