@@ -5,28 +5,52 @@
 from datetime import datetime
 from time import time
 from threading import current_thread
+from os import environ
 
 from pwbus.engines.engine_monitor_event import EngineMonitorEvent
 from pwbus.commons.cprint import cprint
 from sys import stdout, exit
+import random
 
 LOG_DEBUG = True
 LOG_ERROR = True
+date_time = None
+debug_color = 'green'
+
+
+# logging.set_debug_color
+#
+def set_debug_color(color):
+    global debug_color
+    debug_color = color
 
 
 # logging.print_datetime
 #
 def print_datetime(arg1, arg2=''):
-    print(f'{current_thread().getName()} {datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")} ', end='')
-    cprint(
-        arg1,
-        color='bright_white'
-    )
-    cprint(
-        f' {arg2}',
-        color='green'
-    )
-    print()
+    global date_time
+    global debug_color
+    now = datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")
+    this_thread = current_thread().getName()
+    this_thread = "{:<10}".format(this_thread)
+
+    if not date_time or now[0:9] != date_time[0:9]:
+        date_time = now
+        print(this_thread, now, '|-------------------------------------------------------------------')
+
+    print(f'{this_thread[0:10]} {now[10:]} ', end='')
+
+    try:
+        if environ['ENVIRONMENT'] == 'production':
+            print(f'{arg1} {arg2}')
+        else:
+            cprint(arg1, color='bright_white')
+            cprint(f' {arg2}', color=debug_color)
+            print()
+    except:
+        cprint(arg1, color='bright_white')
+        cprint(f' {arg2}', color=debug_color)
+        print()
 
 # logging.getMillis
 #
@@ -35,41 +59,38 @@ def print_datetime(arg1, arg2=''):
 def getMillis():
     return int(round(time() * 1000))
 
+
 # logging.log_debug
 #
-
-
 def log_debug_success(arg1, arg2=''):
     global LOG_DEBUG
     if LOG_DEBUG:
-        print_datetime('SUCES$$ 👍 ', arg1)
+        print_datetime('[GREAT] 👍', arg1)
         if arg2 != '':
-            print_datetime('     $$', arg2)
+            print_datetime('       👍', arg2)
         print("\n")
         stdout.flush()
 
+
 # logging.log_debug
 #
-
-
 def log_debug(arg1, arg2=''):
     global LOG_DEBUG
     if LOG_DEBUG:
-        print_datetime('Debug::', arg1)
+        print_datetime('[DEBUG]::', arg1)
         if arg2 != '':
-            print_datetime('     ::', arg2)
+            print_datetime('       ::', arg2)
         stdout.flush()
 
+
 # logging.log_debug_var
 #
-
-
 def log_debug_var(key, value, arg1=''):
     global LOG_DEBUG
     if LOG_DEBUG:
-        print_datetime(f'Debug>> {key} = [{value}]')
+        print_datetime(f'[DEBUG]>> {key} = [{value}]')
         if arg1 != '':
-            print_datetime('     >>', arg1)
+            print_datetime('       >>', arg1)
         stdout.flush()
 
 # logging.log_error
@@ -83,7 +104,7 @@ def log_error(traceback, message):
     if LOG_DEBUG:
         formatted_lines = traceback.format_exc().splitlines()
         print_datetime(
-            f'ERROR## 🟥 {message}\n     ## Message: {formatted_lines[-1]}')
+            f'[ERROR]## 🟥 {message}\n       ## Message: {formatted_lines[-1]}')
         traceback.print_exc()
         stdout.flush()
 
@@ -94,7 +115,7 @@ def log_error(traceback, message):
 def log_fatal(message):
     EngineMonitorEvent().pushEvent(
         {"type": "fatal", "message": message, "exception": ""})
-    print_datetime('FATAL!! 🟥 Exiting with fatal error -', message)
+    print_datetime('[FATAL]!! 🟥 Exiting with fatal error -', message)
     exit()
 
 
@@ -104,9 +125,9 @@ def log_message_dump(message, message_dump):
     global LOG_DEBUG
     if LOG_DEBUG:
         if message_dump:
-            print_datetime(f'DUMP .. {message} - message: {message_dump}')
+            print_datetime(f'[DUMP] .. {message} - message: {message_dump}')
         else:
-            print_datetime(f'DUMP .. {message} - empty message')
+            print_datetime(f'[DUMP] .. {message} - empty message')
         stdout.flush()
 
 # logging.log_exit
@@ -114,7 +135,7 @@ def log_message_dump(message, message_dump):
 
 
 def log_exit(arg1):
-    print_datetime('EXIT !! 🟥 ', arg1)
+    print_datetime('[EXIT] !! 🟥 ', arg1)
     exit()
 
 # logging.log_warn
@@ -124,7 +145,7 @@ def log_exit(arg1):
 def log_warn(arg1, arg2=''):
     global LOG_DEBUG
     if LOG_DEBUG:
-        print_datetime('WARN:: ⚠️ ', arg1)
+        print_datetime('[WARN]  :: ⚠️ ', arg1)
         if arg2 != '':
-            print_datetime('     ::', arg2)
+            print_datetime('       ::', arg2)
         stdout.flush()
